@@ -1,16 +1,13 @@
 from datetime import datetime
 from dateutil.tz import tzlocal
-try:
-    from collections.abc import Iterable  # Python 3
-except ImportError:
-    from collections import Iterable  # Python 2.7
+from collections.abc import Iterable
 from warnings import warn
 import copy as _copy
 
 import numpy as np
 import pandas as pd
 
-from hdmf.utils import docval, getargs, fmt_docval_args, call_docval_func, get_docval
+from hdmf.utils import docval, getargs, call_docval_func, get_docval
 
 from . import register_class, CORE_NAMESPACE
 from .base import TimeSeries, ProcessingModule
@@ -62,8 +59,7 @@ class Subject(NWBContainer):
              'doc': 'datetime of date of birth. May be supplied instead of age.'})
     def __init__(self, **kwargs):
         kwargs['name'] = 'subject'
-        pargs, pkwargs = fmt_docval_args(super(Subject, self).__init__, kwargs)
-        super(Subject, self).__init__(*pargs, **pkwargs)
+        call_docval_func(super(Subject, self).__init__, kwargs)
         self.age = getargs('age', kwargs)
         self.description = getargs('description', kwargs)
         self.genotype = getargs('genotype', kwargs)
@@ -293,9 +289,8 @@ class NWBFile(MultiContainerInterface):
             {'name': 'scratch', 'type': (list, tuple),
              'doc': 'scratch data', 'default': None})
     def __init__(self, **kwargs):
-        pargs, pkwargs = fmt_docval_args(super(NWBFile, self).__init__, kwargs)
-        pkwargs['name'] = 'root'
-        super(NWBFile, self).__init__(*pargs, **pkwargs)
+        kwargs['name'] = 'root'
+        call_docval_func(super(NWBFile, self).__init__, kwargs)
         self.fields['session_description'] = getargs('session_description', kwargs)
         self.fields['identifier'] = getargs('identifier', kwargs)
 
@@ -339,7 +334,6 @@ class NWBFile(MultiContainerInterface):
             'invalid_times',
             'units',
             'scratch',
-            'experimenter',
             'experiment_description',
             'session_id',
             'lab',
@@ -348,7 +342,6 @@ class NWBFile(MultiContainerInterface):
             'notes',
             'pharmacology',
             'protocol',
-            'related_publications',
             'slices',
             'source_script',
             'source_script_file_name',
@@ -359,6 +352,16 @@ class NWBFile(MultiContainerInterface):
         for attr in fieldnames:
             setattr(self, attr, kwargs.get(attr, None))
 
+        experimenter = kwargs.get('experimenter', None)
+        if isinstance(experimenter, str):
+            experimenter = (experimenter,)
+        setattr(self, 'experimenter', experimenter)
+
+        related_pubs = kwargs.get('related_publications', None)
+        if isinstance(related_pubs, str):
+            related_pubs = (related_pubs,)
+        setattr(self, 'related_publications', related_pubs)
+
         if getargs('source_script', kwargs) is None and getargs('source_script_file_name', kwargs) is not None:
             raise ValueError("'source_script' cannot be None when 'source_script_file_name' is set")
 
