@@ -1,7 +1,4 @@
 #!/usr/bin/env python
-
-from __future__ import print_function
-
 import warnings
 import re
 import argparse
@@ -12,10 +9,10 @@ import os.path
 import os
 import sys
 import traceback
-import unittest2 as unittest
+import unittest
 from tests.coloredtestrunner import ColoredTestRunner, ColoredTestResult
 
-flags = {'pynwb': 2, 'integration': 3, 'example': 4}
+flags = {'pynwb': 2, 'integration': 3, 'example': 4, 'backwards': 5}
 
 TOTAL = 0
 FAILURES = 0
@@ -114,7 +111,6 @@ def run_integration_tests(verbose=True):
     type_map = pynwb.get_type_map()
 
     tested_containers = {}
-    required_tests = {}
     for test_case in test_cases:
         if not hasattr(test_case, 'container'):
             continue
@@ -125,30 +121,13 @@ def run_integration_tests(verbose=True):
         else:
             tested_containers[container_class].append(test_case._testMethodName)
 
-        if container_class not in required_tests:
-            required_tests[container_class] = list(test_case.required_tests)
-        else:
-            required_tests[container_class].extend(test_case.required_tests)
-
     count_missing = 0
     for container_class in type_map.get_container_classes('core'):
-
         if container_class not in tested_containers:
             count_missing += 1
             if verbose > 1:
                 logging.info('%s missing test case; should define in %s' % (container_class,
                                                                             inspect.getfile(container_class)))
-            continue
-
-        test_methods = tested_containers[container_class]
-        required = required_tests[container_class]
-        methods_missing = set(required) - set(test_methods)
-
-        if methods_missing != set([]):
-            count_missing += 1
-            if verbose > 1:
-                logging.info('%s missing test method(s) \"%s\"; should define in %s' % (
-                    container_class, ', '.join(methods_missing), inspect.getfile(container_class)))
 
     if count_missing > 0:
         logging.info('%d classes missing integration tests in ui_write' % count_missing)
@@ -168,6 +147,8 @@ def main():
                         help='run integration tests')
     parser.add_argument('-e', '--example', action='append_const', const=flags['example'], dest='suites',
                         help='run example tests')
+    parser.add_argument('-b', '--backwards', action='append_const', const=flags['backwards'], dest='suites',
+                        help='run backwards compatibility tests')
     args = parser.parse_args()
     if not args.suites:
         args.suites = list(flags.values())
@@ -202,6 +183,9 @@ def main():
     if flags['integration'] in args.suites:
         run_integration_tests(verbose=args.verbosity)
 
+    if flags['backwards'] in args.suites:
+        run_test_suite("tests/back_compat", "pynwb backwards compatibility tests", verbose=args.verbosity)
+
     final_message = 'Ran %s tests' % TOTAL
     exitcode = 0
     if ERRORS > 0 or FAILURES > 0:
