@@ -1,14 +1,13 @@
-import unittest
-
 import numpy as np
 
 from pynwb import TimeSeries
 from pynwb.misc import IntervalSeries
 from pynwb.behavior import SpatialSeries, BehavioralEpochs, BehavioralEvents, BehavioralTimeSeries, PupilTracking, \
                            EyeTracking, CompassDirection, Position
+from pynwb.testing import TestCase
 
 
-class SpatialSeriesConstructor(unittest.TestCase):
+class SpatialSeriesConstructor(TestCase):
     def test_init(self):
         sS = SpatialSeries('test_sS', np.ones((2, 2)), 'reference_frame', timestamps=[1., 2., 3.])
         self.assertEqual(sS.name, 'test_sS')
@@ -16,7 +15,7 @@ class SpatialSeriesConstructor(unittest.TestCase):
         self.assertEqual(sS.reference_frame, 'reference_frame')
 
 
-class BehavioralEpochsConstructor(unittest.TestCase):
+class BehavioralEpochsConstructor(TestCase):
     def test_init(self):
         data = [0, 1, 0, 1]
         iS = IntervalSeries('test_iS', data, timestamps=[1., 2., 3.])
@@ -25,7 +24,7 @@ class BehavioralEpochsConstructor(unittest.TestCase):
         self.assertEqual(bE.interval_series['test_iS'], iS)
 
 
-class BehavioralEventsConstructor(unittest.TestCase):
+class BehavioralEventsConstructor(TestCase):
     def test_init(self):
         ts = TimeSeries('test_ts', np.ones((2, 2)), 'unit', timestamps=[1., 2., 3.])
 
@@ -33,7 +32,7 @@ class BehavioralEventsConstructor(unittest.TestCase):
         self.assertEqual(bE.time_series['test_ts'], ts)
 
 
-class BehavioralTimeSeriesConstructor(unittest.TestCase):
+class BehavioralTimeSeriesConstructor(TestCase):
     def test_init(self):
         ts = TimeSeries('test_ts', np.ones((2, 2)), 'unit', timestamps=[1., 2., 3.])
 
@@ -41,7 +40,7 @@ class BehavioralTimeSeriesConstructor(unittest.TestCase):
         self.assertEqual(bts.time_series['test_ts'], ts)
 
 
-class PupilTrackingConstructor(unittest.TestCase):
+class PupilTrackingConstructor(TestCase):
     def test_init(self):
         ts = TimeSeries('test_ts', np.ones((2, 2)), 'unit', timestamps=[1., 2., 3.])
 
@@ -49,7 +48,7 @@ class PupilTrackingConstructor(unittest.TestCase):
         self.assertEqual(pt.time_series['test_ts'], ts)
 
 
-class EyeTrackingConstructor(unittest.TestCase):
+class EyeTrackingConstructor(TestCase):
     def test_init(self):
         sS = SpatialSeries('test_sS', np.ones((2, 2)), 'reference_frame', timestamps=[1., 2., 3.])
 
@@ -57,7 +56,7 @@ class EyeTrackingConstructor(unittest.TestCase):
         self.assertEqual(et.spatial_series['test_sS'], sS)
 
 
-class CompassDirectionConstructor(unittest.TestCase):
+class CompassDirectionConstructor(TestCase):
     def test_init(self):
         sS = SpatialSeries('test_sS', np.ones((2, 2)), 'reference_frame', timestamps=[1., 2., 3.])
 
@@ -65,13 +64,9 @@ class CompassDirectionConstructor(unittest.TestCase):
         self.assertEqual(cd.spatial_series['test_sS'], sS)
 
 
-class PositionConstructor(unittest.TestCase):
+class PositionConstructor(TestCase):
     def test_init(self):
         sS = SpatialSeries('test_sS', np.ones((2, 2)), 'reference_frame', timestamps=[1., 2., 3.])
 
         pc = Position(sS)
         self.assertEqual(pc.spatial_series.get('test_sS'), sS)
-
-
-if __name__ == '__main__':
-    unittest.main()
