@@ -1,9 +1,8 @@
-import unittest
-
 from pynwb.device import Device
+from pynwb.testing import TestCase
 
 
-class DeviceConstructorBoth(unittest.TestCase):
+class DeviceConstructorBoth(TestCase):
 
     def test_init(self):
         device = Device(name='device_name')
